Index: /issm/trunk-jpl/externalpackages/windows/windows_environment.sh
===================================================================
--- /issm/trunk-jpl/externalpackages/windows/windows_environment.sh	(revision 12202)
+++ /issm/trunk-jpl/externalpackages/windows/windows_environment.sh	(revision 12203)
@@ -2,5 +2,5 @@
 
 #Where are the configuration files for each compiler: 
-config_dir="$ISSM_TIER/externalpackages/windows/configs"
+config_dir="$ISSM_DIR/externalpackages/windows/configs"
 
 #your choise of compiler: 
@@ -24,5 +24,5 @@
 fi
 
-#finally, out of ISSM_TIER, we need to create an ISSM_TIER_WIN variable for Matlab to pick up on.
-ISSM_TIER_WIN=`cygpath -m $ISSM_TIER`
-export ISSM_TIER_WIN
+#finally, out of ISSM_DIR, we need to create an ISSM_DIR_WIN variable for Matlab to pick up on.
+ISSM_DIR_WIN=`cygpath -m $ISSM_DIR`
+export ISSM_DIR_WIN
